bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 21. Aventiure
___________________________________________________ #### Aventivre wie chriemhilt von wormze schiet #### do si gein den hvnen fvor
###### 1290 | ### Di boten lazen riten | wir svln iv tvn bechant ### wi div chvneginne | fvere dvrch div lant ### oder wa von ir schiden | giselher vnd gernot ### si heten ir gedienet | als in ir triwe daz gebot
###### 1291 | ### vnz an di tvnowe | ce vergen si do ritten ### si begonden vrlovbes | di chvenegin bitten ### wan si wider wolden | riten an den rin ### do ne moht ez ane weinen | von gvten frivnden niht gesin
###### 1292 | ### giselher der snelle | sprach cer swester sin ### swenne daz dv vrowe | bedvrfen wellest min ### ob dir iht gewerre | daz tv dv mir bechant ### so rit ich dir ce dineste | in daz eceln lant
###### 1293 | ### di ir mage waren | chvstes an den mvnt ### vil minnechliche sheiden | sach man an der stvnt ### von rvedgeres | des margraven man ### do fvrt div chvneginne | vil manige meit wolgetan
###### 1294 | ### hvndert vnd viere | di trvgen richiv cleit ### von gemalet richen pfellel | vil der schilde breit ### fvrt man bi den vrowen | nahen vf den wegen ### do cherte von ir dannen | vil manich herlicher degen
###### 1295 | ### si zogeten dannen balde | nider dvrch peyerlant ### do sagte man div maere | da waeren fvr gerant ### vil vnchvnder geste | da noch ein chloster stat ### vnt da daz yn mit flvze | in di tvonowe gat
###### 1296 | ### in der stat ce pazzowe | saz ein bisschof ### di berge wurden laere | vnt ovch des fvrsten hoff ### si ilten gegen den | vff in beyerlant ### da der bisschoff pilgrin | di schoenen criemhilden vant
###### 1297 | ### den recken von dem lande | was do niht ce leit ### do si ir volgen sahen | so manige schone meit ### da trvte man mit ovgen | der edeln ritter chint ### gvte herberge | gap man den gesten sint
###### 1298 | ### der bisschoff mit siner nifteln | ce pazzowe reit ### do daz den bvrgaeren | von der stat wart geseit ### daz dar choeme criemhilt | des fvrsten swester chint ### div wart wol enpfangen | von den chovfliuvten sint
###### 1299 | ### daz si beliben solden | der bisschof hetes wan ### do sprach der herre ecchewart | ez ist vngetan ### wir mvzen varn nider | in rvdgeres lant ### vns wartet vil der degene | wan iz ist in allen wol bechant
###### 1300 | ### div maere nv wol wesse | div schone gotelint ### si bereite sich mit vlize | vnde ir vil edel chint ### ir het enboten rvedger | daz in daz dvehte gvt ### daz si der chveneginne | damite troste den mvt
###### 1301 | ### daz si ir rite engenge | mit den sinen man ### vf zv der ense | do daz wart getan ### do sah man allenthalben | di wege vnmvzech sten ### si begonden gegn den gesten | beidiv riten vnd gen
###### 1302 | ### nv was div chvneginne | ce everdingen chomen ### genvge vz peyerlande | solden si han genomen ### den rovb vf der strazen | nach ir gewonheit ### so heten si den gesten | da getan vil lihte leit
###### 1303 | ### daz was wol vnderstanden | von dem margraven her ### er fvrte tvsent ritter | vnt dannoch mer ### do was ovch chomn gotelint | rvedegeres wip ### mit ir chom herliche | vil maniges edeln rechen lip
###### 1304 | ### do si vber di truowen chomen | bi ense vf daz velt ### do sah man vfgespannen | hvetten vnt gecelt ### da di geste solden | di nahtselde han ### div choste was den gesten | da von rvedger getan
###### 1305 | ### gotelint div schone | di herberge lie ### hinder ir beliben | vf den wegen gie ### mit chlingenden zovmen | manich pfaert wolgetan ### der antpfanch wart vil schone | liep was iz rvedger getan
###### 1306 | ### di in ce beden siten | chomen vf den wegen ### di riten lobeliche | der was vil manich degen ### si pflagen ritterschepfte | daz sach vil manich meit ### ovch was der ritter dienest | niht der kvneginne leit
###### 1307 | ### do zv den gesten chomen | di rvedgeres man ### vil der trvonzzvne | sach man ze berge gan ### von der recken hende | mit ritterlichen siten ### da wart wol ce prise | vor den vrowen do geritten
###### 1308 | ### daz liezen si beliben | do grvzte manich man ### vil gvtliche einander | do fvrten si von dan ### di schonen gotelinden | da si criemhilde sach ### di vrowen dienen chvnden | di heten chleinen gemach
###### 1309 | ### der voget von bechelaren | ce sinem wibe reit ### der edeln margravinne | was daz niht ce leit ### daz er so wol gesvnder | was von rine chomen ### ir was ein teil ir swaere | mit grozen vrevden benomen
###### 1310 | ### do sin het enpfangen | er hiez si vf daz gras ### erbeizen mit den vrowen | swaz ir da mit ir was ### da wart vil vnmvzech | manich edel man ### da wart vrowen dienest | mit grozem vlize getan
###### 1311 | ### do sach div vrowe criemhilt | di margravinne sten ### mit ir gesinde | si ne lie niht naher gen ### daz pferht mit dem zovme | zvchen si began ### vnd bat sich snellechlichen | heben von dem satel dan
###### 1312 | ### den bisschoff sach man wisen | siner swester chint ### in vnd eckewarten | zv gotelinde sint ### da wart vil michel wichen | an der selben stvnt ### do chvste div ellende | an der gotelinden mvnt
###### 1313 | ### do sprach vil minnechlichen | daz rvedgeres wip ### nv wol mich liebiv vrowe | daz ich iweren schonen lip ### han in disen landen | mit minen ovgen gesehen ### mir en chvnde an disen ziten | nimmer lieber geschehen
###### 1314 | ### nv lon iv got sprach criemhilt | vil edeliv gotelint ### sol ich gesvnt beliben | vnd botelvnges chint ### ez mag iv chomn ze liebe | daz ir mich habt gesehen ### in beiden was vnchvnde | daz sider mvse geschen
###### 1315 | ### mit zvehten zv zeinander | gie vil manich meit ### do waren in di recken | mit dieneste vil bereit ### si sazen nach dem grvze | nider vff den chle ### si gewunnen maniger chvende | di in vil vremede waren e
###### 1316 | ### man hiez den vrowen schenchen | ez was wol mitter tach ### daz edel ingesinde | da niht lenger lach ### si riten da si fvnden | manige hvetten breit ### da was den edeln gesten | vil michel dienest bereit
###### 1317 | ### di naht si heten ruwe | vnz an den morgen vrv ### di von bechelaren | bereiten sich darzv ### wi si behalten solden | vil manigen vremden gast ### wol het gehandelt rvedeger | daz in da wenich iht gebrast
###### 1318 | ### div venster an den mvren | sah man offen stan ### div bvrch ce becehelaren | div was vfgetan ### do riten darin di geste | di man vil gerne sach ### den hiez der wirt vil edele | schaffen gvten gemach
###### 1319 | ### div rvedgeres thohter | mit ir gesinde gie ### da si di chveneginne | vil minnechlich enpfie ### da was ovch ir mvter | des margaven wip ### mit liebe wart gegrvezet | vil maniger ivnchvrowen lip
###### 1320 | ### si fiengen sich behanden | vnt giengen dan ### in einen palas witen | der was vil wolgetan ### da div tvonowe | vnder hin vloz ### si sahen gegen dem lvfte | vnde heten chvercewile groz
###### 1321 | ### wes si da mere pflaegen | des en chan ich niht gesagen ### daz in so vbele zogete | daz horte man do chlagen ### di criemhilde recken | wan iz was in leit ### hey waz do gvter degene | mit ir von bechelaren reit
###### 1322 | ### vil minnechlichen dienest | rvdger in bot ### do gap div chvneginne | zwelf armbovge rot ### der gotelinde tohter | vnt also gvt gewant ### daz si niht bezzers brahte | in diz lant
###### 1323 | ### swi ir gnomen waere | der nibelvnge golt ### alle di si gesahen | di machete si ir holt ### noch mit dem chleinem gvte | da si da mohte han ### des wirtes ingesinde | dem wart groziv gabe getan
###### 1324 | ### da widerbot do ere | div vrowe gotelint ### den gesten von dem rine | so gvetliche sint ### daz man der vremden | harte wenich vant ### si trvegen ir gesteine | oder ir vil herlich gewant
###### 1325 | ### do si enbizzen waren | vnt daz si solden dan ### von der hvsfrowen | wart geboten an ### getriwerlicher dienest | daz eceln wip ### da wart vil getrivtet | der ivnchvrowen lip
###### 1326 | ### si sprach cer kveneginne | swenne ivch nv dvnchet gvt ### ich weiz wol daz iz gerne | min lieber vater tvt ### daz er mich zv ziv sendet | in der hivnen lant ### daz si ir getriwe waere | vil wol daz criemhilt ervant
###### 1327 | ### div ross bereitet waren | vnt fver bechelaren chomen ### do hete div edel chveneginne | vrlovp nv genomen ### von rvdgeres wibe | vnd der tohter sin ### do schied ovch sich mit grvze | vil manich schonez magedin
###### 1328 | ### einander si vil selten | gesahen nach den tagen ### vzzer medeliche | vf handen wart getragen ### vil manich goltvaz riche | darinne braht man win ### des gesten zv der straze | si mvsen willechomen sin
###### 1329 | ### ein wirt was da gesezzen | astolt was der genant ### der wiste si di straze | in daz osterlant ### gegen mvtaren | di tvonowe nider ### da wart vil wol gedienet | der kveneginne sider
###### 1330 | ### der bisschoff minnechliche | von siner nietel schiet ### daz si sich wol gehabte | wi vast er ir daz reit ### vnt daz si ir ere chovffte | als helche het getan ### hey waz si grozer eren | sit da cen hivnen gewan
###### 1331 | ### zv der treisem brathe | man di geste dan ### ir pflagen vlizechliche | di rvedegeres man ### vnze daz hivnen | ritten veber lant ### do wart der kvneginne | vil michel ere bechant
###### 1332 | ### bi der treisem hete | der chvnich von hivnen lant ### eine bvrch vil riche | div was vil wol bechant ### geheizen zeyzenmvre | vrov helche saz da e ### vnt pflach so grozer tvgende | daz wefrlich nimmer mer erge
###### 1333 | ### ez en taete danne criemhilt | div also chvnde geben ### si mohte nach ir leide | daz liep vil wol geleben ### daz ir ovch iahen ere | di eceln man ### der si sit grozen vollen | bi den helden gewan
###### 1334 | ### div eceln herschaft | was so wit erchant ### daz man zallen ziten | in sinem hove vant ### di chvnesten recken | von den ie wart vernomen ### vnder cristen vnd vnder heiden | di waren mit im alle chomen
###### 1335 | ### bi im was zallen ziten | daz waetlich mer erge ### cristenlicher orden | vnt ovch der heiden e ### in swi getanem leben | sich ietslicher trvch ### daz schvf des chveniges milte | daz man in allen gap genvch

<<< Übersicht <<< vorige Seite nächste Seite >>>